diff stringlengths 139 3.65k | message stringlengths 8 627 | diff_languages stringclasses 1
value |
|---|---|---|
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -1,4 +1,5 @@
import os
+import sys
from setuptools import setup
# Set external files
@@ -16,7 +17,13 @@ with open(os.path.join(os.path.dirname(__file__), 'requirements.txt')) as f:
os.chdir(os.path.normpath(os.path.join(... | Attempt to fix pip3 packaging.. | py |
diff --git a/registration/auth_urls.py b/registration/auth_urls.py
index <HASH>..<HASH> 100644
--- a/registration/auth_urls.py
+++ b/registration/auth_urls.py
@@ -37,16 +37,19 @@ urlpatterns = [
name='auth_logout'),
url(r'^password/change/$',
auth_views.password_change,
+ {'post_change_red... | Due to overriding the auth url names with auth_ prefix the post_redirects must also be overridden | py |
diff --git a/keyboard/_keyboard_event.py b/keyboard/_keyboard_event.py
index <HASH>..<HASH> 100644
--- a/keyboard/_keyboard_event.py
+++ b/keyboard/_keyboard_event.py
@@ -200,7 +200,7 @@ canonical_names = {
'play/pause': 'play/pause media',
'nummult': '*',
- 'num decimal': '.',
+ 'num decimal': 'decim... | Don't assume . is the decimal for everyone | py |
diff --git a/bcbio/variation/freebayes.py b/bcbio/variation/freebayes.py
index <HASH>..<HASH> 100644
--- a/bcbio/variation/freebayes.py
+++ b/bcbio/variation/freebayes.py
@@ -207,8 +207,8 @@ def call_somatic(line):
We also check that the frequency of the tumor exceeds the frequency of the normal by
a threshol... | Provide additional sensitivity to FreeBayes filtering to capture more true positives in evaluation | py |
diff --git a/holidays/countries/__init__.py b/holidays/countries/__init__.py
index <HASH>..<HASH> 100644
--- a/holidays/countries/__init__.py
+++ b/holidays/countries/__init__.py
@@ -69,7 +69,7 @@ from .netherlands import Netherlands, NL, NLD
from .new_zealand import NewZealand, NZ, NZL
from .nicaragua import Nicarag... | Add `NorthMacedonia` import to __init__ (#<I>) Fix missing import for `NorthMacedonia` class/country. | py |
diff --git a/artifactory.py b/artifactory.py
index <HASH>..<HASH> 100755
--- a/artifactory.py
+++ b/artifactory.py
@@ -31,6 +31,7 @@ import json
import os
import pathlib
import sys
+from itertools import islice
import dateutil.parser
import requests
@@ -204,6 +205,15 @@ def sha1sum(filename):
return sha1.he... | MAX_SIZE for property setter | py |
diff --git a/telethon/tl/session.py b/telethon/tl/session.py
index <HASH>..<HASH> 100644
--- a/telethon/tl/session.py
+++ b/telethon/tl/session.py
@@ -113,9 +113,10 @@ class JsonSession:
else: # str / None
self.session_user_id = session_user_id
- self.device_model = platform.node()
-... | Ensure device model is non-empty (closes #<I>) | py |
diff --git a/safe/gui/widgets/dock.py b/safe/gui/widgets/dock.py
index <HASH>..<HASH> 100644
--- a/safe/gui/widgets/dock.py
+++ b/safe/gui/widgets/dock.py
@@ -651,10 +651,10 @@ class Dock(QtGui.QDockWidget, FORM_CLASS):
(layer not in canvas_layers)):
continue
- # st... | Avoid uninitialized variable. | py |
diff --git a/salt/modules/boto_ec2.py b/salt/modules/boto_ec2.py
index <HASH>..<HASH> 100644
--- a/salt/modules/boto_ec2.py
+++ b/salt/modules/boto_ec2.py
@@ -1070,7 +1070,7 @@ def create_key(key_name, save_path, region=None, key=None, keyid=None,
.. code-block:: bash
- salt myminion boto_ec2.create myk... | Fix a minor typo in docs (#<I>) | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -12,6 +12,7 @@ def read(*paths):
install_requires = read('requirements.txt').splitlines()
+install_requires = ['slacker >= 0.7.3']
try:
import argparse
except ImportError:
@@ -20,7 +21,7 @@ except ImportError:
s... | dump fix, bump to <I> | py |
diff --git a/holoviews/core/element.py b/holoviews/core/element.py
index <HASH>..<HASH> 100644
--- a/holoviews/core/element.py
+++ b/holoviews/core/element.py
@@ -294,8 +294,9 @@ class NdElement(Element, NdMapping):
else:
reduced = tuple(reduce_fn(self.dimension_values(vdim.name))
... | Fix for 0D reduction on NdElements | py |
diff --git a/pymc/database/hdf5.py b/pymc/database/hdf5.py
index <HASH>..<HASH> 100644
--- a/pymc/database/hdf5.py
+++ b/pymc/database/hdf5.py
@@ -241,8 +241,9 @@ class Database(pickle.Database):
objects[node._v_name] = [node,]
# Note that the list vlarrays is in reverse orde... | Fixed apparent bug with VLarrays loading in hdf5.Database. This may be dependent on the pytables version, so needs further checking. git-svn-id: <URL> | py |
diff --git a/salt/cloud/clouds/ec2.py b/salt/cloud/clouds/ec2.py
index <HASH>..<HASH> 100644
--- a/salt/cloud/clouds/ec2.py
+++ b/salt/cloud/clouds/ec2.py
@@ -2561,6 +2561,10 @@ def create(vm_=None, call=None):
transport=__opts__['transport']
)
+ # Ensure that the latest node data is returned
+ no... | Ensure that the latest node data is returned | py |
diff --git a/pydle/features/rfc1459/client.py b/pydle/features/rfc1459/client.py
index <HASH>..<HASH> 100644
--- a/pydle/features/rfc1459/client.py
+++ b/pydle/features/rfc1459/client.py
@@ -188,8 +188,11 @@ class RFC1459Support(BasicClient):
# Connect...
await super().connect(hostname, port, **kwar... | #<I> Fix reconnect resetting the password - pydle will ignore password=None if it already has a password | py |
diff --git a/f5/conftest.py b/f5/conftest.py
index <HASH>..<HASH> 100644
--- a/f5/conftest.py
+++ b/f5/conftest.py
@@ -1,3 +1,18 @@
+# Copyright 2015 F5 Networks Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obta... | Insert license into conftest.py. | py |
diff --git a/unixtimestampfield/fields.py b/unixtimestampfield/fields.py
index <HASH>..<HASH> 100644
--- a/unixtimestampfield/fields.py
+++ b/unixtimestampfield/fields.py
@@ -55,9 +55,6 @@ class TimestampPatchMixin(object):
Py2 doesn't supports timestamp()
"""
- if hasattr(v, 'timestamp'):
- ... | Remove timezone related-funtion, use computation | py |
diff --git a/wolframalpha/__init__.py b/wolframalpha/__init__.py
index <HASH>..<HASH> 100644
--- a/wolframalpha/__init__.py
+++ b/wolframalpha/__init__.py
@@ -85,7 +85,7 @@ class Result(object):
@property
def details(self):
''' Get a simplified set of answers with some context. '''
- return {p... | Fix unseen error. Result of one of the previous changes. Almost didn't notice it. | py |
diff --git a/tests/test_util.py b/tests/test_util.py
index <HASH>..<HASH> 100644
--- a/tests/test_util.py
+++ b/tests/test_util.py
@@ -4,14 +4,18 @@ from doctest import DocTestSuite
from tempfile import NamedTemporaryFile, TemporaryDirectory
from unittest import TestCase
+import runcommands.util.decorators
+import ... | Change how doctests are set up Import modules to be doctested and pass them into the `DocTestSuite` constructor rather than the string names of the modules. It's possible modernizing the package structure broke something. In particular, it seems that having a module named "string" was confusing doctest. Refs 3efe<I>... | py |
diff --git a/salt/modules/systemd.py b/salt/modules/systemd.py
index <HASH>..<HASH> 100644
--- a/salt/modules/systemd.py
+++ b/salt/modules/systemd.py
@@ -132,7 +132,7 @@ def _untracked_custom_unit_found(name):
'''
unit_path = os.path.join('/etc/systemd/system',
_canonical_unit_n... | systemd.py: stat before iterating over known units A stat is cheap and most units don't reside in /etc/systemd so the expensive operation of gathering all known units and iterating over them can be avoided. | py |
diff --git a/bokeh/models/widgets/inputs.py b/bokeh/models/widgets/inputs.py
index <HASH>..<HASH> 100644
--- a/bokeh/models/widgets/inputs.py
+++ b/bokeh/models/widgets/inputs.py
@@ -159,7 +159,7 @@ class Slider(InputWidget):
callback_policy = Enum(SliderCallbackPolicy, default="throttle", help="""
An enumera... | Fixed the spelling of the "continuous" | py |
diff --git a/djstripe/models/payment_methods.py b/djstripe/models/payment_methods.py
index <HASH>..<HASH> 100644
--- a/djstripe/models/payment_methods.py
+++ b/djstripe/models/payment_methods.py
@@ -26,7 +26,7 @@ class DjstripePaymentMethod(models.Model):
Contains two fields: `id` and `type`:
- `id` is the ... | Added account source type to DjStripePayment Method account sources are relevant for Connected Accounts | py |
diff --git a/scripts/perf/scheduler_dag_execution_timing.py b/scripts/perf/scheduler_dag_execution_timing.py
index <HASH>..<HASH> 100755
--- a/scripts/perf/scheduler_dag_execution_timing.py
+++ b/scripts/perf/scheduler_dag_execution_timing.py
@@ -124,7 +124,8 @@ def create_dag_runs(dag, num_runs, session):
@click.comm... | [AIRFLOW-XXXX] Wrap line under <I> characters (#<I>) | py |
diff --git a/python-air/examples/server.py b/python-air/examples/server.py
index <HASH>..<HASH> 100644
--- a/python-air/examples/server.py
+++ b/python-air/examples/server.py
@@ -16,7 +16,10 @@ class Animal(object):
print args
print "kwargs"
print kwargs
- return self.noise * kwargs['c... | Ensure server handles missing args robustly | py |
diff --git a/astroid/tests/unittest_inference.py b/astroid/tests/unittest_inference.py
index <HASH>..<HASH> 100644
--- a/astroid/tests/unittest_inference.py
+++ b/astroid/tests/unittest_inference.py
@@ -11,7 +11,7 @@
"""tests for the astroid inference capabilities
"""
# pylint: disable=too-many-lines
-import os
+imp... | Disable the open() test on PyPy There's something going on with io/_io on PyPy. io has all its members coming from _io, but _io's members themselves are also coming from _io, so astroid cannot find the actual place where they are defined. | py |
diff --git a/spotify/models/library.py b/spotify/models/library.py
index <HASH>..<HASH> 100644
--- a/spotify/models/library.py
+++ b/spotify/models/library.py
@@ -9,6 +9,15 @@ class Library:
self.user = user
self.__client = client
+ def __repr__(self):
+ return '<spotify.Library: %s>' % (r... | Add repr, eq, ne dunders for spotify.Library | py |
diff --git a/tests/pipeline/test_statistical.py b/tests/pipeline/test_statistical.py
index <HASH>..<HASH> 100644
--- a/tests/pipeline/test_statistical.py
+++ b/tests/pipeline/test_statistical.py
@@ -373,14 +373,14 @@ class StatisticalBuiltInsTestCase(WithTradingEnvironment, ZiplineTestCase):
)
w... | STY: Don't assign variables that won't be created. | py |
diff --git a/pysparkling/fileio/codec/tar.py b/pysparkling/fileio/codec/tar.py
index <HASH>..<HASH> 100644
--- a/pysparkling/fileio/codec/tar.py
+++ b/pysparkling/fileio/codec/tar.py
@@ -32,6 +32,8 @@ class Tar(Codec):
with tarfile.open(fileobj=stream, mode='r') as f:
for tar_info in f.getmember... | only read file objects (not directories, ...) from tar archives | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -9,7 +9,7 @@ with codecs.open('requirements.txt','r',encoding='utf-8') as f:
setup(
name='pythainlp',
- version='1.7.0',
+ version='1.7.0.1',
description="Thai natural language processing in Python package."... | PyThaiNLP <I> to <I> | py |
diff --git a/pyocd/probe/jlink_probe.py b/pyocd/probe/jlink_probe.py
index <HASH>..<HASH> 100644
--- a/pyocd/probe/jlink_probe.py
+++ b/pyocd/probe/jlink_probe.py
@@ -1,5 +1,6 @@
# pyOCD debugger
# Copyright (c) 2020 Arm Limited
+# Copyright (c) 2021 Chris Reed
# SPDX-License-Identifier: Apache-2.0
#
# Licensed un... | JLinkProbe: clean up imports. | py |
diff --git a/tests/test_utils.py b/tests/test_utils.py
index <HASH>..<HASH> 100644
--- a/tests/test_utils.py
+++ b/tests/test_utils.py
@@ -39,6 +39,8 @@ class TestSubset(object):
def test_raises_value_error_on_empty_slice(self):
# Subset should not support slices that lead to an empty subset
asse... | Add more test cases to slice-based Subset checks | py |
diff --git a/polyaxon/polyaxon/config_settings/cors.py b/polyaxon/polyaxon/config_settings/cors.py
index <HASH>..<HASH> 100644
--- a/polyaxon/polyaxon/config_settings/cors.py
+++ b/polyaxon/polyaxon/config_settings/cors.py
@@ -37,5 +37,13 @@ class INTERNAL_SERVICES(object): # noqa
VALUES = [
DOCKERIZER,
... | Add ephemeral service CORS | py |
diff --git a/tensorflow_probability/python/distributions/linear_gaussian_ssm_test.py b/tensorflow_probability/python/distributions/linear_gaussian_ssm_test.py
index <HASH>..<HASH> 100644
--- a/tensorflow_probability/python/distributions/linear_gaussian_ssm_test.py
+++ b/tensorflow_probability/python/distributions/linea... | Fix typo potentially causing flakiness in LGSSM test. PiperOrigin-RevId: <I> | py |
diff --git a/glitter/blockadmin/blocks.py b/glitter/blockadmin/blocks.py
index <HASH>..<HASH> 100644
--- a/glitter/blockadmin/blocks.py
+++ b/glitter/blockadmin/blocks.py
@@ -11,6 +11,7 @@ from django.contrib.admin.sites import AdminSite
from django.contrib.admin.utils import unquote
from django.core.exceptions impor... | Change let register inline model admin classes | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -32,7 +32,7 @@ except ImportError:
setuptools.setup(
name='gourde',
- version='0.1.3',
+ version='0.1.4',
include_package_data=True,
install_requires=_INSTALL_REQUIRES,
dependency_links=_DEPENDENCY... | setup.py: Bump to <I> | py |
diff --git a/src/ossos-pipeline/scripts/update_astrometry.py b/src/ossos-pipeline/scripts/update_astrometry.py
index <HASH>..<HASH> 100644
--- a/src/ossos-pipeline/scripts/update_astrometry.py
+++ b/src/ossos-pipeline/scripts/update_astrometry.py
@@ -13,6 +13,8 @@ from ossos.downloads.cutouts import ImageCutoutDownload... | Added TOLERANCE as a parameter. Raise flag if TOLERANCE is exceeded | py |
diff --git a/buildozer/targets/osx.py b/buildozer/targets/osx.py
index <HASH>..<HASH> 100644
--- a/buildozer/targets/osx.py
+++ b/buildozer/targets/osx.py
@@ -69,7 +69,7 @@ class TargetOSX(Target):
self.buildozer.info(
'Downloading Keka as dependency (to install Kivy)')
... | fix keka again. Closes #<I> | py |
diff --git a/isort_kate_plugin.py b/isort_kate_plugin.py
index <HASH>..<HASH> 100644
--- a/isort_kate_plugin.py
+++ b/isort_kate_plugin.py
@@ -22,8 +22,9 @@ along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
"""
-import kate
+i... | Update kate plugin to take advantage of dynamic setting support | py |
diff --git a/cobra/core/Model.py b/cobra/core/Model.py
index <HASH>..<HASH> 100644
--- a/cobra/core/Model.py
+++ b/cobra/core/Model.py
@@ -207,7 +207,9 @@ class Model(Object):
except Exception: # pragma: no cover
new._solver = copy(self.solver) # pragma: no cover
- new.solution = deepco... | feat: do not deepcopy solution object in model.copy() (HT @cdiener) | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -4,7 +4,7 @@ from distutils.core import setup
setup(
name='clif',
- version='0.1.0',
+ version='0.2.0',
author='François Ménabé',
author_email='francois.menabe@gmail.com',
license='MIT License',
@@... | Add dependencies in setup and increment version. | py |
diff --git a/master/buildbot/www/hooks/github.py b/master/buildbot/www/hooks/github.py
index <HASH>..<HASH> 100644
--- a/master/buildbot/www/hooks/github.py
+++ b/master/buildbot/www/hooks/github.py
@@ -223,7 +223,7 @@ class GitHubEventHandler(PullRequestMixin):
debug=self.debug, verify=self.verify)
... | Fix no commit msg crash for Github Pull Requests | py |
diff --git a/bcbio/pipeline/run_info.py b/bcbio/pipeline/run_info.py
index <HASH>..<HASH> 100644
--- a/bcbio/pipeline/run_info.py
+++ b/bcbio/pipeline/run_info.py
@@ -687,6 +687,7 @@ def validate_yaml(yaml_in, yaml_fn):
return
conf = """{"extends": "relaxed",
"rules": {"trailing-spaces": {... | YAML check: avoid errors with window line endings | py |
diff --git a/openfisca_core/simulation_builder.py b/openfisca_core/simulation_builder.py
index <HASH>..<HASH> 100644
--- a/openfisca_core/simulation_builder.py
+++ b/openfisca_core/simulation_builder.py
@@ -17,12 +17,16 @@ from openfisca_core.simulations import Simulation
class SimulationBuilder(object):
def __... | Init simulation builder attributes definitions | py |
diff --git a/src/plotypus/preprocessing.py b/src/plotypus/preprocessing.py
index <HASH>..<HASH> 100644
--- a/src/plotypus/preprocessing.py
+++ b/src/plotypus/preprocessing.py
@@ -402,19 +402,3 @@ class Fourier():
phase_deltas %= 2*pi
return ratios
-
-# @staticmethod
-# def amplitude_ratios(amplitu... | Removed commented out code It will never be used again | py |
diff --git a/flask_restful/fields.py b/flask_restful/fields.py
index <HASH>..<HASH> 100644
--- a/flask_restful/fields.py
+++ b/flask_restful/fields.py
@@ -134,17 +134,15 @@ class Nested(Raw):
class List(Raw):
def __init__(self, cls_or_instance, **kwargs):
super(List, self).__init__(**kwargs)
+ err... | slight refactoring to avoid duplication | py |
diff --git a/tests/test_utils.py b/tests/test_utils.py
index <HASH>..<HASH> 100644
--- a/tests/test_utils.py
+++ b/tests/test_utils.py
@@ -12,6 +12,14 @@ class TestUtils(TestCase):
def test_is_python_3(self):
self.assertIsInstance(utils.is_python_3(), bool)
+ def assertPathEquals(self, a, b):
+ ... | Fix failing test There's no os.path.samefile on Python 2 on Windows. | py |
diff --git a/ca/django_ca/management/commands/list_cas.py b/ca/django_ca/management/commands/list_cas.py
index <HASH>..<HASH> 100644
--- a/ca/django_ca/management/commands/list_cas.py
+++ b/ca/django_ca/management/commands/list_cas.py
@@ -23,4 +23,4 @@ class Command(BaseCommand):
def handle(self, **options):
... | do not use ':' as delimiter (it's also used in the serial) | py |
diff --git a/emma2/msm/analysis/dense/fingerprints.py b/emma2/msm/analysis/dense/fingerprints.py
index <HASH>..<HASH> 100644
--- a/emma2/msm/analysis/dense/fingerprints.py
+++ b/emma2/msm/analysis/dense/fingerprints.py
@@ -32,7 +32,6 @@ def fingerprint_correlation(P, obs1, obs2=None, tau=1):
Returns
---... | [msm/analysis/dense] Slight modifications to the fingerprint_correlation and fingerprint_relaxation functions | py |
diff --git a/pyinfra/api/connectors/ssh.py b/pyinfra/api/connectors/ssh.py
index <HASH>..<HASH> 100644
--- a/pyinfra/api/connectors/ssh.py
+++ b/pyinfra/api/connectors/ssh.py
@@ -43,6 +43,11 @@ from .util import (
EXECUTION_CONNECTOR = True
+class WarningPolicy(MissingHostKeyPolicy):
+ def missing_host_key(self... | Fix the handling when we encounter a missing host key. This now shows a warning as was originally intended. | py |
diff --git a/host/fei4/register.py b/host/fei4/register.py
index <HASH>..<HASH> 100644
--- a/host/fei4/register.py
+++ b/host/fei4/register.py
@@ -266,7 +266,7 @@ class FEI4Register(object):
else:
self.load_configuration_from_hdf5(configuration_file, definition_file)
- def save_configurati... | ENH: if arg is not given, take existing config file | py |
diff --git a/tests/test_myplex.py b/tests/test_myplex.py
index <HASH>..<HASH> 100644
--- a/tests/test_myplex.py
+++ b/tests/test_myplex.py
@@ -123,8 +123,7 @@ def test_myplex_optout(account_once):
utils.wait_until(lambda: enabled() == (False, False))
-@pytest.mark.skip(reason="account.onlineMediaSources() is e... | flag onlineMediaSources required to be authenticated | py |
diff --git a/pytodoist/test/test_api.py b/pytodoist/test/test_api.py
index <HASH>..<HASH> 100644
--- a/pytodoist/test/test_api.py
+++ b/pytodoist/test/test_api.py
@@ -49,7 +49,6 @@ class TodoistAPITest(unittest.TestCase):
def test_login_with_google_failure(self):
response = self.api.login_with_google(self... | Updated TodoistAPITest.test_login_with_google_failure to remove an assertion that is failing due to a change in the Todoist API. It is no longer returning a JSON error - this may be put back in later. | py |
diff --git a/src/transformers/modeling_utils.py b/src/transformers/modeling_utils.py
index <HASH>..<HASH> 100644
--- a/src/transformers/modeling_utils.py
+++ b/src/transformers/modeling_utils.py
@@ -417,7 +417,7 @@ def _load_state_dict_into_model(model_to_load, state_dict, start_prefix):
# PyTorch's `_load_from_... | Delete `state_dict` to release memory as early as possible (#<I>) | py |
diff --git a/persephone/corpus.py b/persephone/corpus.py
index <HASH>..<HASH> 100644
--- a/persephone/corpus.py
+++ b/persephone/corpus.py
@@ -202,13 +202,14 @@ class AbstractCorpus(metaclass=abc.ABCMeta):
""" Returns a set of phonemes found in the corpus. """
phonemes = set()
for fn in os.li... | Fixed bug where .DS_STORE file was loaded as a transcription. | py |
diff --git a/src/lib/gtkapp.py b/src/lib/gtkapp.py
index <HASH>..<HASH> 100644
--- a/src/lib/gtkapp.py
+++ b/src/lib/gtkapp.py
@@ -271,6 +271,7 @@ class Application:
dlg = Gtk.MessageDialog(type=Gtk.MessageType.INFO, buttons=Gtk.ButtonsType.OK,
message_format=self.serv... | Comment on code that changes tray icon after script error is viewed. | py |
diff --git a/src/cwmon/metrics.py b/src/cwmon/metrics.py
index <HASH>..<HASH> 100644
--- a/src/cwmon/metrics.py
+++ b/src/cwmon/metrics.py
@@ -64,8 +64,9 @@ class Metric(metaclass=ABCMeta):
MetricData=[{
'MetricName': self.name,
'Value': self.value,... | fix: usr: Fix actually posting to CloudWatch (had 'Timestamp' in wrong place in payload before). | py |
diff --git a/openquake/hazardlib/sourceconverter.py b/openquake/hazardlib/sourceconverter.py
index <HASH>..<HASH> 100644
--- a/openquake/hazardlib/sourceconverter.py
+++ b/openquake/hazardlib/sourceconverter.py
@@ -770,8 +770,8 @@ class SourceConverter(RuptureConverter):
tom_cls = tom.registry[node['tom']]... | changed eval use by use of float | py |
diff --git a/lib/termineter/interface.py b/lib/termineter/interface.py
index <HASH>..<HASH> 100644
--- a/lib/termineter/interface.py
+++ b/lib/termineter/interface.py
@@ -367,7 +367,9 @@ class InteractiveInterpreter(termineter.cmd.Cmd):
sys.stderr = os.fdopen(savestderr, 'w', 0)
else:
self.print_line(banner... | Use a dedicated ipython directory | py |
diff --git a/curtsies/window.py b/curtsies/window.py
index <HASH>..<HASH> 100644
--- a/curtsies/window.py
+++ b/curtsies/window.py
@@ -62,7 +62,7 @@ class BaseWindow(object):
self._last_rendered_height = height
def render_to_terminal(self, array, cursor_pos=(0, 0)):
- raise NotImplemented
+ ... | Fix raising NotImplementedError NotImplemented is a sentinel object, not an exception type. It was mistakenly used instead of NotImplementedError. | py |
diff --git a/exchangelib/autodiscover.py b/exchangelib/autodiscover.py
index <HASH>..<HASH> 100644
--- a/exchangelib/autodiscover.py
+++ b/exchangelib/autodiscover.py
@@ -14,6 +14,7 @@ from __future__ import unicode_literals
import logging
import os
import shelve
+from socket import timeout as SocketTimeout
import ... | Catch ChunkedEncodingError and other common error classes. Fixes #<I> | py |
diff --git a/gns3server/crash_report.py b/gns3server/crash_report.py
index <HASH>..<HASH> 100644
--- a/gns3server/crash_report.py
+++ b/gns3server/crash_report.py
@@ -40,7 +40,7 @@ class CrashReport:
Report crash to a third party service
"""
- DSN = "sync+https://90fe04368a3e4109b584a116ee03ca87:268ef86c... | New crash report key and doesn't send report for developers | py |
diff --git a/conu/apidefs/backend.py b/conu/apidefs/backend.py
index <HASH>..<HASH> 100644
--- a/conu/apidefs/backend.py
+++ b/conu/apidefs/backend.py
@@ -85,7 +85,10 @@ class Backend(object):
self.logger.info("conu has initiated, welcome to the party!")
self.logger.debug("conu version: %s", version._... | we should provide Backend as context manager | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100755
--- a/setup.py
+++ b/setup.py
@@ -15,7 +15,7 @@ if 'sdist' in sys.argv or 'develop' in sys.argv:
from django.core.management.commands.compilemessages import Command
command = Command()
command.execute(stdout=sys.stderr, verbosity=1)... | setup.py: be specific with except handlers | py |
diff --git a/mpd.py b/mpd.py
index <HASH>..<HASH> 100644
--- a/mpd.py
+++ b/mpd.py
@@ -225,7 +225,7 @@ class MPDClient(object):
def _getitem(self):
items = list(self._readitems())
if len(items) != 1:
- raise ProtocolError, "Expected 1 item, got %i" % len(items)
+ return
... | mpd.py: making _getitem return None if no item is returned update and addid should normally always return a single item, so previously an exception was raised if we got nothing. However, when used in a command_list, only the *last* call to update will return an item. So return None instead of raising an exception if... | py |
diff --git a/exchanges/base.py b/exchanges/base.py
index <HASH>..<HASH> 100644
--- a/exchanges/base.py
+++ b/exchanges/base.py
@@ -46,9 +46,10 @@ class ExchangeBase(object):
if self.data == None:
self.refresh()
- def refresh(self):
+ def refresh(self, callback=None, client_data=None):
... | insert a refresh interface for async calls This adds a refresh callback interface that is intended for use in multithreaded apps that get data from several exchanges. Using a callback interface allows the data to get updated immediately after the caller returns. | py |
diff --git a/examples/lm_finetuning/pregenerate_training_data.py b/examples/lm_finetuning/pregenerate_training_data.py
index <HASH>..<HASH> 100644
--- a/examples/lm_finetuning/pregenerate_training_data.py
+++ b/examples/lm_finetuning/pregenerate_training_data.py
@@ -1,7 +1,3 @@
-# Step 1: Slurp the dataset up, tokenize... | Removing a couple of other old unnecessary comments | py |
diff --git a/parsl/dataflow/dflow.py b/parsl/dataflow/dflow.py
index <HASH>..<HASH> 100644
--- a/parsl/dataflow/dflow.py
+++ b/parsl/dataflow/dflow.py
@@ -116,13 +116,16 @@ class DataFlowKernel(object):
self.workflow_name = self.monitoring.workflow_name
else:
for frame in inspect.stac... | Add debug information about choosing workflow name (#<I>) | py |
diff --git a/forestci/version.py b/forestci/version.py
index <HASH>..<HASH> 100644
--- a/forestci/version.py
+++ b/forestci/version.py
@@ -1,9 +1,9 @@
# Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
_version_major = 0
-_version_minor = 3
+_version_minor = 4
_version_micro = '' # use '' ... | Continuing development towards <I> | py |
diff --git a/salt/output/__init__.py b/salt/output/__init__.py
index <HASH>..<HASH> 100644
--- a/salt/output/__init__.py
+++ b/salt/output/__init__.py
@@ -50,7 +50,7 @@ def try_printout(data, out, opts):
try:
return get_printout('nested', opts)(data).rstrip()
except (KeyError, AttributeEr... | Fix typo from <I>f0e | py |
diff --git a/poetry/console/commands/config.py b/poetry/console/commands/config.py
index <HASH>..<HASH> 100644
--- a/poetry/console/commands/config.py
+++ b/poetry/console/commands/config.py
@@ -4,6 +4,7 @@ import re
from cleo import argument
from cleo import option
+from poetry.core.pyproject import PyProjectExcep... | Catch PyProjectException when pyproject.toml is empty | py |
diff --git a/helusers/pipeline.py b/helusers/pipeline.py
index <HASH>..<HASH> 100644
--- a/helusers/pipeline.py
+++ b/helusers/pipeline.py
@@ -13,13 +13,13 @@ User = get_user_model()
logger = logging.getLogger(__name__)
-def ensure_uuid_match(details, backend, response, *args, **kwargs):
+def ensure_uuid_match(det... | Fix a bug in ensure_uuid_match In some cases, the function didn't log the user out as intended. | py |
diff --git a/allauth/socialaccount/providers/line/views.py b/allauth/socialaccount/providers/line/views.py
index <HASH>..<HASH> 100644
--- a/allauth/socialaccount/providers/line/views.py
+++ b/allauth/socialaccount/providers/line/views.py
@@ -45,6 +45,7 @@ class LineOAuth2Adapter(OAuth2Adapter):
else:
... | fix(line): Error handling Let line raise error earlier when requests.get returns with an errornous response | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -48,6 +48,9 @@ setuptools.setup(
'slugs = slugs.app:main'
]
},
+ install_requires=[
+ "cherrypy"
+ ],
classifiers=[
"Environment :: Web Environment",
"Framework ::... | Update the setup script to explicitly list dependencies | py |
diff --git a/ffmpeg/dag.py b/ffmpeg/dag.py
index <HASH>..<HASH> 100644
--- a/ffmpeg/dag.py
+++ b/ffmpeg/dag.py
@@ -170,7 +170,8 @@ def topo_sort(start_nodes):
child_map[node].append(child)
if node not in sorted_nodes:
marked_nodes.append(node)
- [visit(parent, node) for par... | #<I>: don't rely on in | py |
diff --git a/mongo_connector/doc_managers/solr_doc_manager.py b/mongo_connector/doc_managers/solr_doc_manager.py
index <HASH>..<HASH> 100755
--- a/mongo_connector/doc_managers/solr_doc_manager.py
+++ b/mongo_connector/doc_managers/solr_doc_manager.py
@@ -186,13 +186,11 @@ class DocManager():
try:
... | fix: avoid StopIteration in bulk_upsert in solr_doc_manager.py | py |
diff --git a/audit_reading.py b/audit_reading.py
index <HASH>..<HASH> 100644
--- a/audit_reading.py
+++ b/audit_reading.py
@@ -58,8 +58,8 @@ def graph_audit(filename, measurers, output_image_file):
plt.title(header_line)
plt.axis([0,1,0,1.1]) # Make all the plots consistently sized.
plt.xlabel("Repair Level")
... | Resized graphs so legend fits on image. | py |
diff --git a/dhcpcanon/timers.py b/dhcpcanon/timers.py
index <HASH>..<HASH> 100644
--- a/dhcpcanon/timers.py
+++ b/dhcpcanon/timers.py
@@ -121,6 +121,7 @@ def gen_renewing_time(lease_time, elapsed=0):
renewing_time = int(lease_time) * RENEW_PERC - elapsed
# FIXME: the random intervals here could deanonymize
... | log the timers "fuzz" | py |
diff --git a/tests/openwrt/test_context.py b/tests/openwrt/test_context.py
index <HASH>..<HASH> 100644
--- a/tests/openwrt/test_context.py
+++ b/tests/openwrt/test_context.py
@@ -52,9 +52,9 @@ class TestContext(unittest.TestCase, _TabsMixin):
def test_no_variables_found(self):
config = {
"gen... | Corrected text_context: test_no_variables_found This unit test made no sense at all. Now it really tests a possible use case. | py |
diff --git a/mailer/__init__.py b/mailer/__init__.py
index <HASH>..<HASH> 100644
--- a/mailer/__init__.py
+++ b/mailer/__init__.py
@@ -1,10 +1,12 @@
-VERSION = (0, 1, 0, "final")
+VERSION = (0, 2, 0, "dev", 1)
def get_version():
- if VERSION[3] != "final":
- return "%s.%s.%s%s" % (VERSION[0], VERSION[1], V... | master is <I> and modified version code for development releases | py |
diff --git a/doc/conf.py b/doc/conf.py
index <HASH>..<HASH> 100644
--- a/doc/conf.py
+++ b/doc/conf.py
@@ -49,6 +49,7 @@ intersphinx_mapping = {
'numpy': ('http://docs.scipy.org/doc/numpy/', None),
'scipy': ('http://docs.scipy.org/doc/scipy/reference/', None),
'pandas': ('http://pandas-docs.github.io/pan... | * add matplotlib to intersphinx * remove matplotlib url from sphinx-gallery due to errors during compilation | py |
diff --git a/minimongo/test.py b/minimongo/test.py
index <HASH>..<HASH> 100644
--- a/minimongo/test.py
+++ b/minimongo/test.py
@@ -164,7 +164,6 @@ class TestSimpleModel(unittest.TestCase):
self.assertEqual(indices['x_1'],
{'key': [('x', 1)]})
-
def test_unique_index(self):
... | Fixed bad test for previous changeset, pep8 | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100755
--- a/setup.py
+++ b/setup.py
@@ -62,6 +62,8 @@ setup(name="ctypeslib",
author="Thomas Heller",
author_email="theller@ctypes.org",
license="MIT License",
+ version = "0.5.0",
+
## url="http://starship.python.net/crew/thelle... | Add a version number to the setup script (only to experiment with easy_install). git-svn-id: <URL> | py |
diff --git a/facebook/__init__.py b/facebook/__init__.py
index <HASH>..<HASH> 100755
--- a/facebook/__init__.py
+++ b/facebook/__init__.py
@@ -115,7 +115,7 @@ class GraphAPI(object):
def get_connections(self, id, connection_name, **args):
"""Fetchs the connections for given object."""
return self... | Allow passing integers to get_connections. Resolve #<I>. | py |
diff --git a/searx/engines/digg.py b/searx/engines/digg.py
index <HASH>..<HASH> 100644
--- a/searx/engines/digg.py
+++ b/searx/engines/digg.py
@@ -32,6 +32,9 @@ title_xpath = './/h2//a//text()'
content_xpath = './/p//text()'
pubdate_xpath = './/time'
+digg_cookie_chars = string.ascii_uppercase + string.ascii_lowerc... | [fix] digg cookie characters created in module import | py |
diff --git a/py_css_styleguide/__init__.py b/py_css_styleguide/__init__.py
index <HASH>..<HASH> 100644
--- a/py_css_styleguide/__init__.py
+++ b/py_css_styleguide/__init__.py
@@ -1,2 +1,2 @@
"""CSS Manifest driven styleguide for your project"""
-__version__ = '0.2.0-pre.1'
+__version__ = '0.2.0-pre.2' | Forgotted to increment pre release version | py |
diff --git a/test/unittest_inference.py b/test/unittest_inference.py
index <HASH>..<HASH> 100644
--- a/test/unittest_inference.py
+++ b/test/unittest_inference.py
@@ -870,14 +870,14 @@ def f(x):
if sys.version_info < (2, 5):
self.skip('require py >= 2.5')
data = "from ...common import dat... | oops, should not have changed this | py |
diff --git a/cocaine/tools/dispatch.py b/cocaine/tools/dispatch.py
index <HASH>..<HASH> 100644
--- a/cocaine/tools/dispatch.py
+++ b/cocaine/tools/dispatch.py
@@ -549,7 +549,7 @@ def app_view(name, **kwargs):
@app_group.command(name='upload')
-@click.argument('path', default=os.path.curdir, type=click.Path(exists=... | fix: path option is no longer required | py |
diff --git a/nautilus/services/serviceManager.py b/nautilus/services/serviceManager.py
index <HASH>..<HASH> 100644
--- a/nautilus/services/serviceManager.py
+++ b/nautilus/services/serviceManager.py
@@ -40,6 +40,7 @@ class ServiceManager:
port=int(port),
)
+
@group.command(help=... | added cleardb command to service manager ; resolves #7 | py |
diff --git a/spacy/cli/train.py b/spacy/cli/train.py
index <HASH>..<HASH> 100644
--- a/spacy/cli/train.py
+++ b/spacy/cli/train.py
@@ -467,7 +467,6 @@ def train(
# Update model meta.json
meta["lang"] = nlp.lang
meta["pipeline"] = nlp.pipe_names
- ... | Don't override spaCy version | py |
diff --git a/autofit/messages/abstract.py b/autofit/messages/abstract.py
index <HASH>..<HASH> 100644
--- a/autofit/messages/abstract.py
+++ b/autofit/messages/abstract.py
@@ -115,17 +115,15 @@ class AbstractMessage(Prior, ABC):
def ndim(self) -> int:
return self._broadcast.ndim
+ @classmethod
+ de... | adding cached_attrs to get all cached properties | py |
diff --git a/omego/version.py b/omego/version.py
index <HASH>..<HASH> 100644
--- a/omego/version.py
+++ b/omego/version.py
@@ -52,6 +52,7 @@ def call_git_describe(abbrev=4):
def read_release_version():
try:
parent = path.dirname(__file__)
+ parent = path.dirname(parent)
filename = path.jo... | RELEASE-VERSION is one dir up | py |
diff --git a/alot/ui.py b/alot/ui.py
index <HASH>..<HASH> 100644
--- a/alot/ui.py
+++ b/alot/ui.py
@@ -120,12 +120,12 @@ class UI(object):
def fire(ignored, cmdline):
clear()
logging.debug("cmdline: '%s'" % cmdline)
- # move keys are always passed
... | fix: fix Command mechanism for move cmds in non-locked state | py |
diff --git a/commitizen/commands/commit.py b/commitizen/commands/commit.py
index <HASH>..<HASH> 100644
--- a/commitizen/commands/commit.py
+++ b/commitizen/commands/commit.py
@@ -28,7 +28,10 @@ class Commit:
self.config: BaseConfig = config
self.cz = factory.commiter_factory(self.config)
self... | fix(commit): attach user info to backup for permission denied issue When multi users commit in the same machine shared backup will cause permission deny. To resolve this issue, attach user info to the name of backup commit. | py |
diff --git a/Server/Python/src/dbs/dao/Oracle/Dataset/List.py b/Server/Python/src/dbs/dao/Oracle/Dataset/List.py
index <HASH>..<HASH> 100644
--- a/Server/Python/src/dbs/dao/Oracle/Dataset/List.py
+++ b/Server/Python/src/dbs/dao/Oracle/Dataset/List.py
@@ -3,8 +3,8 @@
This module provides Dataset.List data access object... | conn test was incorrect From: afaq <afaq> git-svn-id: svn+ssh://svn.cern.ch/reps/CMSDMWM/DBS/trunk@<I> <I>e-<I>-<I>b1-a<I>-d<I>a<I>b | py |
diff --git a/stanza/utils/training/run_ner.py b/stanza/utils/training/run_ner.py
index <HASH>..<HASH> 100644
--- a/stanza/utils/training/run_ner.py
+++ b/stanza/utils/training/run_ner.py
@@ -31,6 +31,7 @@ from stanza.resources.prepare_resources import default_charlms, default_treebank
# extra arguments specific to a... | dropout <I> seems to work better (small dataset?) | py |
diff --git a/fireplace/managers.py b/fireplace/managers.py
index <HASH>..<HASH> 100644
--- a/fireplace/managers.py
+++ b/fireplace/managers.py
@@ -85,6 +85,7 @@ class PlayerManager(Manager):
GameTag.CANT_DRAW: "cant_draw",
GameTag.CARDTYPE: "type",
GameTag.COMBO_ACTIVE: "combo",
+ GameTag.CONTROLLER: "control... | Add a CONTROLLER tag for Player as well We need this in our new design for affiliation testing. It's not ideal, but for now it's the simplest way to do it. | py |
diff --git a/distributions.py b/distributions.py
index <HASH>..<HASH> 100644
--- a/distributions.py
+++ b/distributions.py
@@ -364,8 +364,8 @@ class GaussianFixedCov(_GaussianBase, GibbsSampling, MaxLikelihood):
def __init__(self,sigma,mu_0,lmbda_0,mu=None):
self.mu_0 = mu_0
self.sigma = sigma
- ... | removed 'bad form' comments about np.linalg.inv, i think it's appropriate there! | py |
diff --git a/pymc3/tests/test_model_helpers.py b/pymc3/tests/test_model_helpers.py
index <HASH>..<HASH> 100644
--- a/pymc3/tests/test_model_helpers.py
+++ b/pymc3/tests/test_model_helpers.py
@@ -80,7 +80,7 @@ class TestHelperFunc:
# Check function behavior with Theano graph variable
theano_output = fu... | update test to accommodate int type casting | py |
diff --git a/graypy/__init__.py b/graypy/__init__.py
index <HASH>..<HASH> 100644
--- a/graypy/__init__.py
+++ b/graypy/__init__.py
@@ -20,4 +20,4 @@ except ImportError:
pass # amqplib is probably not installed
-__version__ = (1, 1, 2)
+__version__ = (1, 1, 3) | bumping to version `<I>` | py |
diff --git a/clever_selects/form_fields.py b/clever_selects/form_fields.py
index <HASH>..<HASH> 100644
--- a/clever_selects/form_fields.py
+++ b/clever_selects/form_fields.py
@@ -1,9 +1,11 @@
+from __future__ import absolute_import
+
from django.core import validators
from django.core.exceptions import ValidationErro... | Update form_fields.py This is a simple Python 3 compatibility fix. This style of relative import is deprecated. | py |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
diff --git a/grammpy/Rule.py b/grammpy/Rule.py
index <HASH>..<HASH> 100644
--- a/grammpy/Rule.py
+++ b/grammpy/Rule.py
@@ -11,7 +11,9 @@ from .Constants import EPSILON
class Rule:
- #TODO rules -> rule -> left/right -> rules
+ #TODO rules -> rule -> left/right -> fromSymbol/toSymbol -> rules
+ fromSymbol ... | Add fromSymbol and toSymbol to rule | py |